@@ -8,6 +8,7 @@ from classiq_interface.generator.arithmetic import (
     Arithmetic,
     Equal,
     ArithmeticOracle,
+    Negation,
 )
 from classiq_interface.generator.finance import Finance
 from classiq_interface.generator.function_params import FunctionParams
@@ -25,6 +26,8 @@ from classiq_interface.generator.amplitude_estimation import AmplitudeEstimation
 from classiq_interface.generator.entangler_params import HypercubeEntangler
 from classiq_interface.generator.entangler_params import GridEntangler
 from classiq_interface.generator.mcx import Mcx
+from classiq_interface.generator.custom_function import CustomFunction
+
 
 _function_param_list = {
     StatePreparation,
@@ -39,6 +42,7 @@ _function_param_list = {
     Arithmetic,
     ArithmeticOracle,
     Equal,
+    Negation,
     TwoDimensionalEntangler,
     IntegerComparator,
     Finance,
@@ -49,6 +53,7 @@ _function_param_list = {
     HadamardAmpLoad,
     GroverOperator,
     Mcx,
+    CustomFunction,
 }
 
 
