@@ -1,8 +1,10 @@
+import base64
 import enum
+import io
 from typing import Union, List, Optional
 
 import pydantic
-
+from PIL import Image
 from classiq_interface.generator.generation_metadata import GenerationMetadata
 
 
@@ -27,6 +29,10 @@ class GeneratedCircuit(pydantic.BaseModel):
     image: str
     metadata: GenerationMetadata
 
+    def show(self) -> None:
+        image = Image.open(io.BytesIO(base64.b64decode(self.image)))
+        image.show()
+
 
 class GenerationResult(pydantic.BaseModel):
     status: GenerationStatus
